==> react-payment-icons-1.1.2.tgz: package/src/remoteImages.js <==
export const FLAGS_SVGS_URLS = {
  amex: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/amex.svg',
  aura: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/aura.svg',
  boleto: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/boleto.svg',
  cirrus: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/cirrus.svg',
  credit_card: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/credit-card.svg',
  diners: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/diners.svg',
  direct_debit: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/direct_debit.svg',
  discover: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/discover.svg',
  ebay: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/ebay.svg',
  elo: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/elo.svg',
  eway: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/eway.svg',
  jcb: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/jcb.svg',
  maestro: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/maestro.svg',
  mastercard: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/mastercard.svg',
  sage: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/sage.svg',
  shopify: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/shopify.svg',
  skrill: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/skrill.svg',
  skrill_moneybookers: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/skrill_moneybookers.svg',
  solo: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/solo.svg',
  visa: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/visa.svg',
  visa_electron: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/visa_electron.svg',
  western: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/western.svg',
  worldpay: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/worldpay.svg',
};

export const BANKS_SVGS_URLS = {
  boleto: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/boleto.svg',
  bb: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/bb.svg',
  bradesco: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/bradesco.svg',
  caixa: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/caixa.svg',
  hsbc: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/hsbc.svg',
  itau: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/itau.svg',
  santander: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/santander.svg',
};

export const FACILITATORS_SVGS_URLS = {
  amazon: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/amazon.svg',
  wallet: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/wallet.svg',
  paypal: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/paypal.svg',
  cielo: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/cielo.svg',
  global: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/global.svg',
  pagseguro: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/pagseguro.svg',
  rede: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/rede.svg',
  stone: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/stone.svg',
  elavon: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/elavon.svg',
};

export const UNKNOWN_SVGS_URLS = {
  generic: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/generic.svg',
};

==> react-payment-icons-1.2.0.tgz: package/src/remoteImages.js <==
const AMAZON_URL = 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods';

export const FLAGS_SVGS_URLS = {
  amex: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/amex.svg',
  aura: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/aura.svg',
  boleto: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/boleto.svg',
  cirrus: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/cirrus.svg',
  credit_card: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/credit-card.svg',
  diners: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/diners.svg',
  direct_debit: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/direct_debit.svg',
  discover: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/discover.svg',
  ebay: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/ebay.svg',
  elo: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/elo.svg',
  eway: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/eway.svg',
  jcb: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/jcb.svg',
  maestro: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/maestro.svg',
  mastercard: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/mastercard.svg',
  sage: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/sage.svg',
  shopify: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/shopify.svg',
  skrill: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/skrill.svg',
  skrill_moneybookers: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/skrill_moneybookers.svg',
  solo: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/solo.svg',
  visa: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/visa.svg',
  visa_electron: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/visa_electron.svg',
  western: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/western.svg',
  worldpay: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/worldpay.svg',
};

export function getBankSvgUrls(key, transparent = false) {
  const transparentStr = transparent ? '_transparent' : '';
  const BANKS_SVGS_URLS = {
    boleto: `${AMAZON_URL}/boleto${transparentStr}.svg`,
    bb: `${AMAZON_URL}/bb${transparentStr}.svg`,
    bradesco: `${AMAZON_URL}/bradesco${transparentStr}.svg`,
    caixa: `${AMAZON_URL}/caixa${transparentStr}.svg`,
    hsbc: `${AMAZON_URL}/hsbc${transparentStr}.svg`,
    itau: `${AMAZON_URL}/itau${transparentStr}.svg`,
    santander: `${AMAZON_URL}/santander${transparentStr}.svg`,
  };

  return BANKS_SVGS_URLS[key];
}

export function getFacilitatorSvgUrl(key, transparent = false) {
  const transparentStr = transparent ? '_transparent' : '';
  const FACILITATORS_SVGS_URLS = {
    amazon: `${AMAZON_URL}/amazon${transparentStr}.svg`,
    wallet: `${AMAZON_URL}/wallet${transparentStr}.svg`,
    paypal: `${AMAZON_URL}/paypal${transparentStr}.svg`,
    cielo: `${AMAZON_URL}/cielo${transparentStr}.svg`,
    global: `${AMAZON_URL}/global${transparentStr}.svg`,
    pagseguro: `${AMAZON_URL}/pagseguro${transparentStr}.svg`,
    rede: `${AMAZON_URL}/rede${transparentStr}.svg`,
    stone: `${AMAZON_URL}/stone${transparentStr}.svg`,
    elavon: `${AMAZON_URL}/elavon${transparentStr}.svg`,
  };

  return FACILITATORS_SVGS_URLS[key];
}

export const UNKNOWN_SVGS_URLS = {
  generic: 'https://s3-sa-east-1.amazonaws.com/azpay-checkout/payment-methods/generic.svg',
};
